Module: Tutorial
- Defined in:
- lib/tutorial.rb
Overview
Contains methods to display tutorial screens
Instance Method Summary collapse
Instance Method Details
#my_list ⇒ Object
20 21 22 23 24 25 26 27 28 29 30 31 |
# File 'lib/tutorial.rb', line 20 def my_list system('clear') puts '》 MY LIST 《'.colorize(:light_green) puts 'My List is the base that your recommendations are generated from. It can consist of' puts "up to 5 of any 'items'. An item is either a track, artist or genre. You can add and remove" puts 'items from my list, so make sure to change them up regularly to get a range of recommendations!' puts "Searching for an item will return the top 5 results for your keywords, so if yours doesn't show" puts 'up, try searching again with a more specific query!' puts @prompt.keypress('Press any key to continue..') recommendations end |
#playlist ⇒ Object
45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/tutorial.rb', line 45 def playlist system('clear') puts '》 PLAYLIST 《'.colorize(:light_green) puts "Your playlist stores all of the recommendations you've chosen, but you can also manually add and" puts "remove songs as well. This can all be done from the playlist menu. At any point you'd like to look" puts 'at your playlist outside of Spotify Rec, you can export the contents to a file on your desktop.' puts 'This file includes a link to each song on Spotify, so you can easily go and start listening!' puts @prompt.keypress('Press any key to return to finish..') exit end |
#recommendations ⇒ Object
33 34 35 36 37 38 39 40 41 42 43 |
# File 'lib/tutorial.rb', line 33 def recommendations system('clear') puts '》 RECOMMENDATIONS 《'.colorize(:light_green) puts 'As mentioned on the previous screen, recommendations are tracks, and are generated based on the' puts "items in your list. You can select the amount you'd like to generate, and select any number of" puts 'the recommendations to store in your playlist. Recommendations are capped at 10 per generate,' puts 'but you can repeat the generate step as many times as you would like.' puts @prompt.keypress('Press any key to continue..') playlist end |
#start ⇒ Object
7 8 9 10 11 12 13 14 15 16 17 18 |
# File 'lib/tutorial.rb', line 7 def start system('clear') puts '》 WELCOME TO SPOTIFY REC 《'.colorize(:light_green) puts 'This tutorial will walk you through the basics to using the app.' puts "There are 3 main areas that you'll need to understand:" puts '- My List' puts '- Recommendations' puts '- Playlist' puts @prompt.keypress('Press any key to continue..') my_list end |